@@ -23,6 +23,7 @@
 #include <QApplication>
 #include <QCommandLineOption>
 #include <QCommandLineParser>
+#include <QQuickStyle>
 #include <QQuickView>
 
 #include <iostream>
@@ -46,15 +47,23 @@
 #include <QtAndroid>
 #endif
 
+using namespace Qt::StringLiterals;
+
 int main(int argc, char **argv)
 {
     QApplication app(argc, argv);
+#ifndef Q_OS_ANDROID
+    // Default to org.kde.desktop style unless the user forces another style
+    if (qEnvironmentVariableIsEmpty("QT_QUICK_CONTROLS_STYLE")) {
+        QQuickStyle::setStyle(QStringLiteral("org.kde.desktop"));
+    }
+#endif
     KLocalizedString::setApplicationDomain("koko");
 
     KAboutData aboutData(QStringLiteral("koko"),
-                         xi18nc("@title", "<application>Koko</application>"),
+                         xi18nc("@title", "<application>Photos</application>"),
                          QStringLiteral(KOKO_VERSION_STRING),
-                         xi18nc("@title", "Koko is an image viewer for your image collection."),
+                         xi18nc("@title", "Photos is an image viewer for your image collection."),
                          KAboutLicense::LGPL,
                          xi18nc("@info:credit", "(c) 2013-2020 KDE Contributors"),
                          QString(),
@@ -86,7 +95,7 @@ int main(int argc, char **argv)
     parser.process(app);
     aboutData.processCommandLine(&parser);
 
-    QApplication::setWindowIcon(QIcon::fromTheme(QStringLiteral("koko")));
+    QApplication::setWindowIcon(QIcon::fromTheme(QStringLiteral("org.kde.koko")));
 
     if (parser.isSet("reset") || ImageStorage::shouldReset()) {
         ImageStorage::reset();
@@ -170,34 +179,19 @@ int main(int argc, char **argv)
                          }
                      });
 
-    qmlRegisterSingletonInstance("org.kde.koko.private", 0, 1, "OpenFileModel", &openFileModel);
-    qmlRegisterType<VectorImage>("org.kde.koko.image", 0, 1, "VectorImage");
-    qmlRegisterType<FileMenu>("org.kde.koko.private", 0, 1, "FileMenu");
+    qmlRegisterSingletonInstance("org.kde.koko.private", 1, 0, "OpenFileModel", &openFileModel);
+    qmlRegisterType<VectorImage>("org.kde.koko.image", 1, 0, "VectorImage");
+    qmlRegisterType<FileMenu>("org.kde.koko.private", 1, 0, "FileMenu");
 
     Controller controller;
-    qmlRegisterSingletonInstance("org.kde.koko.private", 0, 1, "Controller", &controller);
+    qmlRegisterSingletonInstance("org.kde.koko.private", 1, 0, "Controller", &controller);
 
     engine.rootContext()->setContextProperty("kokoProcessor", &processor);
     engine.rootContext()->setContextProperty("kokoConfig", &config);
-    engine.rootContext()->setContextProperty(QStringLiteral("kokoAboutData"), QVariant::fromValue(aboutData));
 
     // we want different main files on desktop or mobile
     // very small difference as they as they are subclasses of the same thing
-    engine.load(QUrl(QStringLiteral("qrc:/qml/Main.qml")));
-
-#ifndef Q_OS_ANDROID
-    const auto rootObjects = engine.rootObjects();
-    for (auto obj : rootObjects) {
-        auto view = qobject_cast<QQuickWindow *>(obj);
-        if (view) {
-            KConfig dataResource(QStringLiteral("data"), KConfig::SimpleConfig, QStandardPaths::AppDataLocation);
-            KConfigGroup windowGroup(&dataResource, "Window");
-            KWindowConfig::restoreWindowSize(view, windowGroup);
-            KWindowConfig::restoreWindowPosition(view, windowGroup);
-            break;
-        }
-    }
-#endif
+    engine.loadFromModule(u"org.kde.koko"_s, u"Main"_s);
 
     int rt = app.exec();
     trackerThread.quit();
